/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package apoc.generate.distribution;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;

/**
 * Simple {@link DegreeDistribution} where the distribution can be directly passed into the constructor.
 */
public class MutableSimpleDegreeDistribution extends SimpleDegreeDistribution implements MutableDegreeDistribution {

    public MutableSimpleDegreeDistribution(List<Integer> degrees) {
       super(degrees);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void set(int index, int value) {
        degrees.set(index, value);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void decrease(int index) {
        degrees.set(index, degrees.get(index) - 1);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void sort(Comparator<Integer> comparator) {
        Collections.sort(degrees, comparator);
    }
}
